#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hpack
version:              0.34.3
visibility:           public
id:                   hpack-0.34.3-7t30mqhDqJ82auKOTQNM4t
key:                  hpack-0.34.3-7t30mqhDqJ82auKOTQNM4t
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  bac59f85c673bc6944fb7984be706f9d
exposed:              True
exposed-modules:      Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Path Paths_hpack

import-dirs:          /usr/lib/ghc-8.10.2/site-local/hpack-0.34.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hpack-0.34.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/hpack-0.34.3
hs-libraries:         HShpack-0.34.3-7t30mqhDqJ82auKOTQNM4t
depends:
    Cabal-3.2.0.0 Glob-0.10.1-HufowHFwEAX2daULFz6rUb
    aeson-1.5.5.1-7ZKmq9KLIncxnBfAj9HU2 base-4.14.1.0
    bifunctors-5.5.9-FI6DXtjiJyzBQISUOBX7DC bytestring-0.10.10.0
    containers-0.6.2.1 cryptonite-0.27-HHsLwS0rDVxGOErqbxkj0C
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1
    http-client-0.7.3-GITCtCtFnIrEyRFmonyFH9
    http-client-tls-0.3.5.3-34s9LsWJRNY3uIPEnuxDII
    http-types-0.12.3-BjgB5kCegWL53v8V6hA7Kx
    infer-license-0.2.0-2Zp29R1aS9eFmIfFUDt8ms pretty-1.1.3.6
    scientific-0.3.6.2-Es7urXKqj0FVel3uHj76m text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-HeBOjfSts31GSj9apQxnyX
    vector-0.12.1.2-IO5RJnkQnAxDAG50LdixTd
    yaml-0.11.5.0-ESAKkZWDHkD8oVKLu7aj5h

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

